==> aliyun-python-sdk-imm-1.1.0.tar.gz: aliyun-python-sdk-imm-1.1.0/aliyunsdkimm/request/v20170906/DeleteFaceSetRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class DeleteFaceSetRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'DeleteFaceSet','imm')

	def get_LazyMode(self):
		return self.get_query_params().get('LazyMode')

	def set_LazyMode(self,LazyMode):
		self.add_query_param('LazyMode',LazyMode)

	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)

	def get_SetId(self):
		return self.get_query_params().get('SetId')

	def set_SetId(self,SetId):
		self.add_query_param('SetId',SetId)

	def get_CheckEmpty(self):
		return self.get_query_params().get('CheckEmpty')

	def set_CheckEmpty(self,CheckEmpty):
		self.add_query_param('CheckEmpty',CheckEmpty)

==> aliyun-python-sdk-imm-1.6.2.tar.gz: aliyun-python-sdk-imm-1.6.2/aliyunsdkimm/request/v20170906/DeleteFaceSetRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class DeleteFaceSetRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'DeleteFaceSet','2017-09-06')

	def get_LazyMode(self):
		return self.get_query_params().get('LazyMode')

	def set_LazyMode(self,LazyMode):
		self.add_query_param('LazyMode',LazyMode)

	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)

	def get_SetId(self):
		return self.get_query_params().get('SetId')

	def set_SetId(self,SetId):
		self.add_query_param('SetId',SetId)

	def get_CheckEmpty(self):
		return self.get_query_params().get('CheckEmpty')

	def set_CheckEmpty(self,CheckEmpty):
		self.add_query_param('CheckEmpty',CheckEmpty)
